@@ -1,7 +1,7 @@
 /*
  * vi: formatoptions+=tc textwidth=80 tabstop=8 shiftwidth=8 noexpandtab:
  *
- * $Id: concordance.c,v 1.37 2009/03/08 18:52:41 jaymzh Exp $
+ * $Id: concordance.c,v 1.41 2010/08/01 15:28:53 jaymzh Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -112,7 +112,7 @@ int set_canon(int flag)
 #define DEFAULT_FW_FILENAME_BIN "firmware.bin"
 #define DEFAULT_SAFE_FILENAME "safe.bin"
 
-const char * const VERSION = "0.21";
+const char * const VERSION = "0.22";
 
 struct options_t {
 	int binary;
@@ -467,6 +467,11 @@ int upload_config(uint8_t *data, uint32_t size, struct options_t *options,
 			post_preconfig(data, size);
 	}
 
+	printf("Preparing Update:    ");
+	if ((err = prep_config())) {
+		return err;
+	}
+	printf("                     done\n");
 	/*
 	 * We must invalidate flash before we erase and write so that
 	 * nothing will attempt to reference it while we're working.
@@ -500,6 +505,12 @@ int upload_config(uint8_t *data, uint32_t size, struct options_t *options,
 	}
 	printf("       done\n");
 
+	printf("Finalizing Update:   ");
+	if ((err = finish_config())) {
+		return err;
+	}
+	printf("                     done\n");
+
 	if ((*options).noreset) {
 		return 0;
 	}
@@ -598,6 +609,7 @@ int upload_firmware(uint8_t *firmware, uint32_t firmware_size,
 	} else {
 		if ((err = extract_firmware_binary(firmware, firmware_size,
 				&firmware_bin, &firmware_bin_size))) {
+			printf("Failed to extract firmware from file\n");
 			delete_blob(firmware_bin);
 			return err;
 		}
