@@ -1,7 +1,7 @@
 #
 # vi: formatoptions+=tc textwidth=80 tabstop=8 shiftwidth=4 expandtab:
 #
-# $Id: libconcord.py,v 1.6 2009/03/08 18:52:41 jaymzh Exp $
+# $Id: libconcord.py,v 1.9 2010/08/01 15:55:17 jaymzh Exp $
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ debug = (os.environ.get("LIBCONCORD_PY_TRACE", "0") == "1")
 # Define the libconcord ABI this libconcord.py corresponds to
 # Bump this when the .so file version gets bumped
 
-ABI_VERSION = 1
+ABI_VERSION = 2
 
 # Load the DLL
 
@@ -636,6 +636,18 @@ verify_remote_config = _create_func(
     _in('cb_arg', py_object)
 )
 
+# int prep_config();
+prep_config = _create_func(
+    'prep_config',
+    _ret_lc_concord()
+)
+
+# int finish_config();
+finish_config = _create_func(
+    'finish_config',
+    _ret_lc_concord()
+)
+
 # int erase_config(uint32_t size, lc_callback cb, void *cb_arg);
 erase_config = _create_func(
     'erase_config',
@@ -687,14 +699,14 @@ write_safemode_to_file = _create_func(
 # int is_fw_update_supported(int direct);
 is_fw_update_supported = _create_func(
     'is_fw_update_supported',
-    _ret_lc_concord(),
+    c_int,
     _in('direct', c_int)
 )
 
 # int is_config_safe_after_fw();
 is_config_safe_after_fw = _create_func(
     'is_config_safe_after_fw',
-    _ret_lc_concord()
+    c_int
 )
 
 # int prep_firmware();
